==> Xarm-1.3.1.tar.gz: Xarm-1.3.1/include/Xarm/XarmAll.h <==
/* $Id: XarmAll.h,v 1.3 1999/02/03 13:50:22 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined _XARM_ALL_H_
#define _XARM_ALL_H_

#include <Xarm/AppContext.h>
#include <Xarm/ApplicationS.h>
#include <Xarm/ArrowB.h>
#include <Xarm/ArrowBG.h>
#include <Xarm/BulletinB.h>
#include <Xarm/Callback.h>
#include <Xarm/CascadeB.h>
#include <Xarm/CascadeBG.h>
#include <Xarm/ComboBox.h>
#include <Xarm/Command.h>
#include <Xarm/Dial.h>
#include <Xarm/DialogS.h>
#include <Xarm/Display.h>
#include <Xarm/DragDrop.h>
#include <Xarm/DrawingA.h>
#include <Xarm/DrawnB.h>
#include <Xarm/FileSB.h>
#include <Xarm/Form.h>
#include <Xarm/Frame.h>
#include <Xarm/Gauge.h>
#include <Xarm/Label.h>
#include <Xarm/LabelG.h>
#include <Xarm/List.h>
#include <Xarm/MainW.h>
#include <Xarm/MenuB.h>
#include <Xarm/MenuShell.h>
#include <Xarm/MessageB.h>
#include <Xarm/Page.h>
#include <Xarm/PanedW.h>
#include <Xarm/PasswordF.h>
#include <Xarm/Property.h>
#include <Xarm/PushB.h>
#include <Xarm/PushBG.h>
#include <Xarm/RootW.h>
#include <Xarm/RowColumn.h>
#include <Xarm/Scale.h>
#include <Xarm/Screen.h>
#include <Xarm/ScrollBar.h>
#include <Xarm/ScrolledW.h>
#include <Xarm/SelectioB.h>
#include <Xarm/SeparatoG.h>
#include <Xarm/Separator.h>
#include <Xarm/Text.h>
#include <Xarm/TextF.h>
#include <Xarm/ToggleB.h>
#include <Xarm/ToggleBG.h>
#include <Xarm/VendorS.h>
#include <Xarm/WorkArea.h>
#include <Xarm/XarmArg.h>
#include <Xarm/XarmCaption.h>
#include <Xarm/XarmMatrix.h>
#include <Xarm/XarmWidget.h>

#endif

==> Xarm-1.4.0.tar.gz: Xarm-1.4.0/include/Xarm/XarmAll.h <==
/* $Id: XarmAll.h,v 1.6 1999/12/25 18:34:49 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 Copyright (C) 1999       Gerald L. Gay
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_xarmall_h)
#define xarm_xarmall_h

#include <Xarm/AppContext.h>
#include <Xarm/ApplicationS.h>
#include <Xarm/ArrowB.h>
#include <Xarm/ArrowBG.h>
#include <Xarm/BulletinB.h>
#include <Xarm/Callback.h>
#include <Xarm/CascadeB.h>
#include <Xarm/CascadeBG.h>
#include <Xarm/ComboBox.h>
#include <Xarm/Command.h>
#include <Xarm/Dial.h>
#include <Xarm/DialogS.h>
#include <Xarm/Display.h>
#include <Xarm/DragDrop.h>
#include <Xarm/DrawingA.h>
#include <Xarm/DrawnB.h>
#include <Xarm/FileSB.h>
#include <Xarm/Form.h>
#include <Xarm/Frame.h>
#include <Xarm/Gauge.h>
#include <Xarm/Label.h>
#include <Xarm/LabelG.h>
#include <Xarm/List.h>
#include <Xarm/MainW.h>
#include <Xarm/MenuB.h>
#include <Xarm/MenuShell.h>
#include <Xarm/MessageB.h>
#include <Xarm/Page.h>
#include <Xarm/PanedW.h>
#include <Xarm/PasswordF.h>
#include <Xarm/Property.h>
#include <Xarm/PushB.h>
#include <Xarm/PushBG.h>
#include <Xarm/RootW.h>
#include <Xarm/RowColumn.h>
#include <Xarm/Scale.h>
#include <Xarm/Screen.h>
#include <Xarm/ScrollBar.h>
#include <Xarm/ScrolledW.h>
#include <Xarm/SelectioB.h>
#include <Xarm/SeparatoG.h>
#include <Xarm/Separator.h>
#include <Xarm/Text.h>
#include <Xarm/TextF.h>
#include <Xarm/ToggleB.h>
#include <Xarm/ToggleBG.h>
#include <Xarm/VendorS.h>
#include <Xarm/WorkArea.h>
#include <Xarm/XarmArg.h>
#include <Xarm/XarmCaption.h>
#include <Xarm/XarmMatrix.h>
#include <Xarm/XarmWidget.h>
#include <Xarm/GLWidgets.h>

#endif
